# This Code is part of the following publication:
# Schwarzmueller, F. & Kastner, T (2022), Agricultural trade and its impact on cropland use
# and the global loss of species' habitats. Sustainability Science, doi: 10.1007/s11625-022-01138-7
#
#
# Please cite ;-)
# (c) Florian Schwarzmller, December 2021

rm(list=ls())  #clears the work environment

directory <- choose.dir(caption="Please select the working directory")

setwd(directory)

#### Unzip data ####

## To unzip the data from FAOSTAT, please execute the following line (can be skipped if already done) 
source("Unzip data.R")



#### select options ####
## In this section, you can select the years for which to do the analysis (1986 until 2013 are available),
## the way in which to convert traded items into primary products, and whether to prefer reported import or export data
## Please refer to the original manuscript and the accompanying Appendices to learn more about these options

# select years for which to calculate the results (1986 to 2013)
for_years <- seq(1986,2013,1)


# select a conversion method
# possible inputs: ("dry_matter","Energy","Protein","Fiber_TD","Zinc","Iron","Calcium",
#                   "Folate_Tot","Riboflavin","Choline_Tot","Potassium","Vit_E","Vit_B12",
#                   "Vit_K","Vit_A")

conversion_opt= "dry_matter"

# select whether to prefer reported import or export data
# possible inputs: ("import","export")
prefer_import = "import"


#### calls R-scripts ####
for(included_years in for_years){

# Calculates the apparent consumption and respective trade links  
source("Calculating_Trade_Matrix.R")

# Converts animal products into embedded feed items  
source("animal_products_to_feed.R")
  
# converts traded tons into areas #

source("calculate_area.R")
}
