# This Code is part of the following publication:
# Schwarzmueller, F. & Kastner, T (2022), Agricultural trade and its impact on cropland use
# and the global loss of species' habitats. Sustainability Science, doi: 10.1007/s11625-022-01138-7
#
#
# Please cite ;-)
# (c) Florian Schwarzmller, December 2021

#### some initial things ####
#rm(list=ls())  #clears the work environment
rm(list= setdiff(ls(),c("directory","included_years", "conversion_opt","prefer_import"))) # use this when run externally 


### function to read in required packages
packages <- function(packagelist){
  for (package in packagelist) {
    if(!require(package, character.only = T)){
      install.packages(package, dependencies = T)
      require(package, character.only = T)
    }
  }
}

packagelist <- list("data.table", "tidyverse","readxl")
packages(packagelist)

if (!exists("directory")) { 
  directory <- choose.dir()
  #directory <- ("C:\\Users\\fschwarzmueller\\Documents\\projekte\\einstieg\\FAO_Data\\V2\\")
}
setwd(directory)

if (!exists("included_years")){
  included_years <- 2013
}

if(!exists("prefer_import")){
  prefer_import = "import"
}
# conversion method into primary items ("dry_matter","Energy","Protein","Fiber_TD","Zinc","Iron","Calcium",
#                                       "Folate_Tot","Riboflavin","Choline_Tot","Potassium","Vit_E","Vit_B12",
#                                       "Vit_K","Vit_A")
if(!exists("conversion_opt")){
  conversion_opt = "dry_matter"
}


trade.matrix.file <-paste("results\\TradeMatrixFeed_",prefer_import,"_",conversion_opt,"_",included_years,".csv",sep="")
trade.data <- fread(trade.matrix.file)

yield.data.file <-"Production_Crops_E_All_Data_(Normalized).csv"
yield.data <- fread(yield.data.file)
names(yield.data)<- str_replace_all(names(yield.data),c(" "="_"))

yield.data <- yield.data[yield.data$Element=="Yield",]

yield.data <- rename(yield.data,Producer_Country_Code=Area_Code, Yield=Value)

area.data <- left_join(trade.data,yield.data, by=c("Producer_Country_Code","Year","Item_Code"))
area.data <- area.data %>% mutate(Area=(as.numeric(Value)*10000)/(Yield))

fwrite(select(area.data,Consumer_Country_Code, Producer_Country_Code,Item_Code,Animal_Product_Code,Year,Value,Area), 
       paste(unlist(strsplit(trade.matrix.file,"[.]"))[1],"_Area.csv",sep=""))                                                   
